@@ -53,6 +53,7 @@ public:
     void resize(int width, int height) override { Q_UNUSED(width); Q_UNUSED(height) }
     Mir::State state() const override { return Mir::RestoredState; }
     bool live() const override { return true; }
+    bool isReady() const override { return true; }
     bool visible() const override { return true; }
     Mir::OrientationAngle orientationAngle() const override { return Mir::Angle0; }
     void setOrientationAngle(Mir::OrientationAngle angle) override { Q_UNUSED(angle); }
@@ -118,7 +119,7 @@ public:
     QUrl icon() const override { return QUrl(); }
     ApplicationInfoInterface::State state() const override { return ApplicationInfoInterface::Running; }
     bool focused() const override { return m_focused; }
-    bool showSplash() const override { return false; }
+    bool showSplash() const override { return true; }
     QString splashTitle() const override { return QString(); }
     QUrl splashImage() const override { return QUrl(); }
     bool splashShowHeader() const override { return true; }
